EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'FeedAdapters_CreateOrUpdateFeedAdapter',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new feed adapter or updates an existing one.'
GO

IF OBJECT_ID('[FeedAdapters_CreateOrUpdateFeedAdapter]') IS NOT NULL DROP PROCEDURE [FeedAdapters_CreateOrUpdateFeedAdapter]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [FeedAdapters_CreateOrUpdateFeedAdapter]
(
	@Feed_Id INT,
	@FeedAdapter_Sequence INT = NULL OUT,
	@FeedAdapter_Name NVARCHAR(50),
	@FeedAdapterType_Code VARCHAR(8),
	@FeedAdapter_Configuration VARCHAR(MAX)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT * FROM [FeedAdapters] WITH (UPDLOCK) WHERE [Feed_Id] = @Feed_Id AND [FeedAdapter_Sequence] = @FeedAdapter_Sequence)
	BEGIN

		UPDATE [FeedAdapters]
		   SET [FeedAdapter_Name] = @FeedAdapter_Name,
		       [FeedAdapterType_Code] = @FeedAdapterType_Code,
			   [FeedAdapter_Configuration] = @FeedAdapter_Configuration
		 WHERE [Feed_Id] = @Feed_Id
		   AND [FeedAdapter_Sequence] = @FeedAdapter_Sequence

	END
	ELSE
	BEGIN

		SET @FeedAdapter_Sequence = (SELECT COALESCE(MAX([FeedAdapter_Sequence]),0) + 1
		                               FROM [FeedAdapters]
		                               WITH (UPDLOCK)
		                              WHERE [Feed_Id] = @Feed_Id)

		INSERT INTO [FeedAdapters]
		(
			[Feed_Id],
			[FeedAdapter_Sequence],
			[FeedAdapter_Name],
			[FeedAdapterType_Code],
			[FeedAdapter_Configuration]
		)
		VALUES
		(
			@Feed_Id,
			@FeedAdapter_Sequence,
			@FeedAdapter_Name,
			@FeedAdapterType_Code,
			@FeedAdapter_Configuration
		)

	END

	EXEC [Events_RaiseEvent] 'FEDMDF', @Feed_Id, 'FeedAdapterType_Code', @FeedAdapterType_Code
	
	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [FeedAdapters_CreateOrUpdateFeedAdapter] TO [ProGetUser_Role]
GO
	   

