EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'NuGetPackages_SetListed',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Lists or unlists a NuGet package.'
GO

IF OBJECT_ID('[NuGetPackages_SetListed]') IS NOT NULL DROP PROCEDURE [NuGetPackages_SetListed]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO


CREATE PROCEDURE [NuGetPackages_SetListed]
(
	@Feed_Id INT,
	@Package_Id NVARCHAR(255),
	@Version_Text NVARCHAR(50),
	@Listed_Indicator YNINDICATOR
)
AS
BEGIN

SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON

BEGIN TRY
	BEGIN TRANSACTION

	SET @Version_Text = (SELECT CAST((CAST([Major] AS NVARCHAR(10))
	                         + (CASE WHEN [Minor] IS NOT NULL THEN '.' + CAST([Minor] AS NVARCHAR(10)) ELSE '' END)
						     + (CASE WHEN [Patch] IS NOT NULL THEN '.' + CAST([Patch] AS NVARCHAR(10)) ELSE '' END)
						     + (CASE WHEN [Build] IS NOT NULL THEN '.' + CAST([Build] AS NVARCHAR(10)) ELSE '' END)
						     + (CASE WHEN [Prerelease] IS NOT NULL THEN '-' + [Prerelease] ELSE '' END)) AS NVARCHAR(50))
	                       FROM dbo.ParseNuGetVersion(@Version_Text))

	UPDATE [NuGetPackages]
	   SET [Listed_Indicator] = @Listed_Indicator
	 WHERE [Feed_Id] = @Feed_Id
	   AND [Package_Id] = @Package_Id 
	   AND [Version_Text] = @Version_Text

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [NuGetPackages_SetListed] TO [ProGetUser_Role]